@@ -1,10 +1,10 @@
 """apgw API."""
 from asyncpg import Connection
 
+from .connection_wrapper import ConnectionWrapper
 from .constraint import (Assignments, BinaryConstraint, Constraints,
                          DictConstraint, GroupConstraint, Literal,
                          MappedPlaceholder, TextConstraint)
-from .db import DB, DBBase
 from .exceptions import RollbackTransactionException
-from .types import (ConnectionArgs, LimitOffset, Record, Records,
-                    RecordsAndCount)
+from .types import (ConnectionArgs, ExecuteResult, LimitOffset, Record,
+                    Records, RecordsAndCount)
