@@ -3,7 +3,7 @@ from collections import OrderedDict
 from dataclasses import dataclass
 from typing import Any, Callable, List, Union
 
-from apgw.types import Params
+from .types import Params
 
 
 @dataclass(frozen=True)
